@@ -10,7 +10,9 @@ from transformers import (PreTrainedTokenizerBase,
                           TrainingArguments,
                           Trainer,
                           PrinterCallback,
-                          EarlyStoppingCallback)
+                          EarlyStoppingCallback,
+                          RobertaForSequenceClassification,
+                          RobertaForTokenClassification)
 from typing import Dict, Optional, Tuple, List, Any
 import numpy as np
 import requests
@@ -259,13 +261,29 @@ class BaseBenchmark(ABC):
                 params = dict()
 
             try:
-                config = AutoConfig.from_pretrained(model_id, **params)
+                # If the model ID specifies a random model, then load that.
+                if model_id.startswith('random'):
+                    rnd_id = 'xlm-roberta-base'
+                    config = AutoConfig.from_pretrained(rnd_id, **params)
 
-                model_cls = self._get_model_class(framework=framework)
+                    if model_id == 'random-roberta-sequence-clf':
+                        model_cls = RobertaForSequenceClassification
+                    elif model_id == 'random-roberta-token-clf':
+                        model_cls = RobertaForTokenClassification
+                    else:
+                        raise ValueError(f'A random model was chosen, '
+                                         f'"{model_id}", but it was not '
+                                         f'recognized.')
 
-                model = model_cls.from_pretrained(model_id,
-                                                  config=config,
-                                                  cache_dir=self.cache_dir)
+                    model = model_cls(config)
+
+                # Otherwise load the pretrained model
+                else:
+                    config = AutoConfig.from_pretrained(model_id, **params)
+                    model_cls = self._get_model_class(framework=framework)
+                    model = model_cls.from_pretrained(model_id,
+                                                      config=config,
+                                                      cache_dir=self.cache_dir)
 
                 # Get the `label2id` and `id2label` conversions from the model
                 # config
@@ -380,7 +398,15 @@ class BaseBenchmark(ABC):
                         try:
                             clf_weight = model.classifier.weight.data
                         except AttributeError:
-                            clf_weight = model.classifier.out_proj.weight.data
+                            try:
+                                clf_weight = (model.classifier
+                                                   .out_proj
+                                                   .weight
+                                                   .data)
+                            except AttributeError:
+                                msg = ('Model does not seem to be a '
+                                       'classification model.')
+                                raise InvalidBenchmark(msg)
 
                         # Create the new weights, which have zeros at all the
                         # new entries
@@ -414,10 +440,20 @@ class BaseBenchmark(ABC):
             # If the model is a subclass of a RoBERTa model then we have to add
             # a prefix space to the tokens, by the way the model is
             # constructed.
-            prefix = 'Roberta' in type(model).__name__
-            tokenizer = AutoTokenizer.from_pretrained(model_id,
-                                                      use_fast=True,
-                                                      add_prefix_space=prefix)
+            if model_id.startswith('random'):
+                params = dict(use_fast=True, add_prefix_space=True)
+                tokenizer = AutoTokenizer.from_pretrained(rnd_id, **params)
+            else:
+                prefix = 'Roberta' in type(model).__name__
+                params = dict(use_fast=True, add_prefix_space=prefix)
+                tokenizer = AutoTokenizer.from_pretrained(model_id, **params)
+
+            # Set the maximal length of the tokenizer to the model's maximal
+            # length. This is required for proper truncation
+            try:
+                tokenizer.model_max_length = config.max_position_embeddings
+            except AttributeError:
+                pass
 
             return dict(model=model, tokenizer=tokenizer)
 
@@ -584,6 +620,11 @@ class BaseBenchmark(ABC):
         Raises:
             RuntimeError: If the extracted framework is not recognized.
         '''
+        # If the model ID specifies a random ID, then return a hardcoded
+        # metadata dictionary
+        if model_id.startswith('random'):
+            return dict(task='fill-mask', framework='pytorch')
+
         # Parse all the anchor tags from the model website
         url = 'https://www.huggingface.co/' + model_id
         html = requests.get(url).text
@@ -616,11 +657,11 @@ class BaseBenchmark(ABC):
 
         return dict(framework=framework, task=task)
 
-    def __call__(self,
-                 model_id: str,
-                 progress_bar: bool = True
-                 ) -> Dict[str, List[Dict[str, float]]]:
-        '''Finetune and evaluate a model.
+    def benchmark(self,
+                  model_id: str,
+                  progress_bar: bool = True
+                  ) -> Dict[str, List[Dict[str, float]]]:
+        '''Benchmark a model.
 
         Args:
             model_id (str):
@@ -637,7 +678,6 @@ class BaseBenchmark(ABC):
         Raises:
             RuntimeError: If the extracted framework is not recognized.
         '''
-        # Load the model and its metadata
         model_metadata = self._fetch_model_metadata(model_id)
         framework = model_metadata['framework']
         task = model_metadata['task']
@@ -784,7 +824,7 @@ class BaseBenchmark(ABC):
 
                         break
 
-                    except (RuntimeError, ValueError) as e:
+                    except (RuntimeError, ValueError, IndexError) as e:
                         if not str(e).startswith('CUDA out of memory'):
                             raise InvalidBenchmark(str(e))
                         bs = training_args.per_device_train_batch_size
@@ -885,3 +925,6 @@ class BaseBenchmark(ABC):
         else:
             raise RuntimeError(f'The framework "{framework}" is not '
                                f'supported!')
+
+    def __call__(self, *args, **kwargs):
+        return self.benchmark(*args, **kwargs)
